==> generator-ng-poly-0.12.4.tgz: package/generators/view/index.js <==
'use strict';

require('babel-polyfill');

var _genBase = require('../genBase');

var _genBase2 = _interopRequireDefault(_genBase);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = _genBase2.default.extend({
  prompting: function prompting() {
    return this.askForModuleName();
  },
  writing: function writing() {
    var done, config, markupFile, styleFile;
    return regeneratorRuntime.async(function writing$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            done = this.async();
            _context.next = 3;
            return regeneratorRuntime.awrap(this.getConfig());

          case 3:
            config = _context.sent;
            markupFile = this.name;

            // if markupFile doesn't end with .tpl.html, append it

            if (!/[.]tpl[.]html$/.test(this.name)) {
              markupFile += '.tpl.html';
            }

            // remove TplHtml from lowerCamel
            config.lowerCamel = config.lowerCamel.replace(/TplHtml$/, '');

            // remove TplHtml from ctrlName
            config.ctrlName = config.ctrlName.replace(/TplHtml$/, '');

            // create the style file
            styleFile = markupFile.replace(/tpl[.]html$/, config.style);

            // replace file extension with markup type being used

            markupFile = markupFile.replace(/html$/, config.markup);

            _context.next = 12;
            return regeneratorRuntime.awrap(Promise.all([this.copyFile('markup', 'view', _path2.default.join(config.appDir, config.modulePath, config.structure === 'module-type' ? 'views' : '', markupFile), config), this.copyStyleFile('view', _path2.default.join(config.appDir, config.modulePath, config.structure === 'module-type' ? 'views' : '', styleFile), config)]));

          case 12:

            done();

          case 13:
          case 'end':
            return _context.stop();
        }
      }
    }, null, this);
  }
});

==> generator-ng-poly-0.13.0.tgz: package/generators/view/index.js <==
'use strict';

require('babel-polyfill');

var _genBase = require('../genBase');

var _genBase2 = _interopRequireDefault(_genBase);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = _genBase2.default.extend({
  prompting: function prompting() {
    return this.askForModuleName();
  },
  writing: function writing() {
    var config, markupFile, styleFile;
    return regeneratorRuntime.async(function writing$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return regeneratorRuntime.awrap(this.getConfig());

          case 2:
            config = _context.sent;
            markupFile = this.name;

            // if markupFile doesn't end with .tpl.html, append it

            if (!/[.]tpl[.]html$/.test(this.name)) {
              markupFile += '.tpl.html';
            }

            // remove TplHtml from lowerCamel
            config.lowerCamel = config.lowerCamel.replace(/TplHtml$/, '');

            // remove TplHtml from ctrlName
            config.ctrlName = config.ctrlName.replace(/TplHtml$/, '');

            // create the style file
            styleFile = markupFile.replace(/tpl[.]html$/, config.style);

            // replace file extension with markup type being used

            markupFile = markupFile.replace(/html$/, config.markup);

            return _context.abrupt('return', Promise.all([this.copyFile('markup', 'view', _path2.default.join(config.appDir, config.modulePath, config.structure === 'module-type' ? 'views' : '', markupFile), config), this.copyStyleFile('view', _path2.default.join(config.appDir, config.modulePath, config.structure === 'module-type' ? 'views' : '', styleFile), config)]));

          case 10:
          case 'end':
            return _context.stop();
        }
      }
    }, null, this);
  }
});
